<?php
/**
 * Cabins in the economy class may use this class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class EconomyCabin extends BaseCabin implements TradeableItem, ConstructableShipPart {
	// Konstruktor
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set description
		$this->setObjectDescription("Economy-Class-Kabine");

		// Generate unique ID number
		$this->generateUniqueId();

		// Clean up a little
		$this->removeSystemArray();
	}

	// Economy-Kabine erstellen
	public final static function createEconomyCabin ($numLuxury, $numRooms, $numBeds, $dim) {
		// Get new instance
		$ecoInstance = new EconomyCabin();

		// Debug message
		if ((defined('DEBUG_CABIN')) || (defined('DEBUG_ALL'))) $ecoInstance->getDebugInstance()->output(sprintf("[%s:%d] Eine Economy-Class-Kabine wird konstruiert...",
			__CLASS__,
			__LINE__
		));

		// Abmasse extrahieren
		$ecoInstance->extractDimensions($dim);

		// Den Rest auch setzen
		$ecoInstance->setNumCabin($numLuxury);
		$ecoInstance->setNumRooms($numRooms);
		$ecoInstance->setNumBeds($numBeds);

		// Nicht noetig!
		$ecoInstance->removePartInstance();

		// Instanz zurueckgeben
		return $ecoInstance;
	}

	// Overwritten method for tradeable items
	public function isTradeable () {
		return true;
	}
}

// [EOF]
?>
