<?php
/**
 * A filter for checking if the user status is UNCONFIRMED
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class UserUnconfirmedVerifierFilter extends BaseFrameworkSystem implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set part description
		$this->setObjectDescription("A filter for checking if the user account is unconfirmed");

		// Create unique ID number
		$this->generateUniqueId();

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public final static function createUserUnconfirmedVerifierFilter () {
		// Get a new instance
		$filterInstance = new UserUnconfirmedVerifierFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get a user instance for comparison
		$userInstance = User::createUserByRequest($requestInstance);

		// Is the user account confirmed?
		if ($userInstance->getField('user_status') != $this->getConfigInstance()->readConfig('user_status_unconfirmed')) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Redirect to configured URL
			$responseInstance->redirectToConfiguredUrl('login_user_unconfirmed_url');

			// Stop processing here
			exit();
		} // END - if

		// Add this instance to registry
		Registry::getRegistry()->addInstance('user', $userInstance);
	}
}

// [EOF]
?>
